==> fim-0.6-rc2.tar.bz2: fim-0.6-rc2/src/version.h <==
"+FIM_ALLOW_LOADER_STRING_SPECIFICATION  "
"+FIM_AUTHOR  "
"+FIM_AUTHOR_EMAIL  "
"+FIM_AUTHOR_NAME  "
"+FIM_AUTOCMDS  "
"+FIM_AUTOSKIP_FAILED  "
"+FIM_BOZ_PATCH  "
"+FIM_CHECK_DUPLICATES  "
"+FIM_CHECK_FILE_EXISTENCE  "
"+FIM_COMMAND_AUTOCOMPLETION  "
"+FIM_CONFIGURATION  "
"+FIM_DEFAULT_CONFIG  "
"+FIM_DEFAULT_CONFIGURATION  "
"+FIM_DEFAULT_KEY_CONFIG  "
"+FIM_EXPERIMENTAL_ROTATION  "
"+FIM_HANDLE_GIF  "
"+FIM_HANDLE_TIFF  "
"+FIM_HAS_TIMEOUT  "
"+FIM_ITERATED_COMMANDS  "
"+FIM_LINUX_CONSOLEFONTS_DIR_SCAN  "
"+FIM_NAMESPACES  "
"+FIM_NOFB  "
"+FIM_PATHS_IN_MAN  "
"+FIM_PIPE_IMAGE_READ  "
"+FIM_RANDOM  "
"+FIM_READ_DIRS  "
"+FIM_READ_STDIN  "
"+FIM_READ_STDIN_IMAGE  "
"+FIM_RECORDING  "
"+FIM_RECURSIVE_DIRS  "
"+FIM_REMOVE_FAILED  "
"+FIM_SKIP_KNOWN_FILETYPES  "
"+FIM_SMART_COMPLETION  "
"+FIM_SWITCH_FIXUP  "
"+FIM_TMP_FILENAME  "
"+FIM_TRY_CONVERT  "
"+FIM_TRY_DIA  "
"+FIM_TRY_INKSCAPE  "
"+FIM_TRY_XFIG  "
"+FIM_USE_READLINE  "
"+FIM_USE_ZCAT  "
"+FIM_VERSION  "
"+FIM_WANT_CUSTOM_INFO_STATUS_BAR  "
"+FIM_WANT_FILENAME_MARK_AND_DUMP  "
"+FIM_WANT_FONT_MAGNIFY_FACTOR  "
"+FIM_WANT_HARDCODED_FONT  "
"+FIM_WANT_LONG_INT  "
"+FIM_WANT_RAW_BITS_RENDERING  "
"+FIM_WANT_SEEK_MAGIC  "
"+FIM_WANT_TEXT_RENDERING  "
"+FIM_WINDOWS  "
"+FIM_WITH_AALIB  "
"+FIM_WITH_BMP  "
"+FIM_WITH_LIBCACA  "
"+FIM_WITH_LIBEXIF  "
"+FIM_WITH_LIBPNG  "
"+FIM_WITH_LIBSDL  "
"+FIM_WITH_PCX  "
"\n"
"FIM_AUTHOR = \"Michele Martone <dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_EMAIL = \"<dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_NAME = \"Michele Martone\"\n"
"FIM_CONFIGURATION = \"./configure CXXFLAGS=-O0\"\n"
"FIM_TMP_FILENAME = \"\"\n"
"FIM_VERSION = \"0.6-rc2\"\n"
"-FIM_BIG_ENDIAN  "
"-FIM_CACHE_DEBUG  "
"-FIM_DEFAULT_CONSOLEFONT  "
"-FIM_KEEP_BROKEN_CONSOLE  "
"-FIM_NOFIMRC  "
"-FIM_NOHISTORY  "
"-FIM_TRY_XCFTOPNM  "
"-FIM_USE_DESIGNATED_INITIALIZERS  "
"-FIM_WANTS_SLOW_RESIZE  "
"-FIM_WANT_EXIFTOOL  "
"-FIM_WANT_FB_CONSOLE_SWITCH_WHILE_LOADING  "
"-FIM_WANT_NOSCRIPTING  "
"-FIM_WANT_NO_OUTPUT_CONSOLE  "
"-FIM_WANT_STATIC_BINARY  "
"-FIM_WITH_ARCHIVE  "
"-FIM_WITH_DEBUG  "
"-FIM_WITH_LIBIMLIB2  "
"-FIM_WITH_LIBJASPER  "
"-FIM_WITH_LIBXYZ  "
"-FIM_WITH_NO_FRAMEBUFFER  "
"-FIM_WITH_UFRAW  "

==> fim-0.7.0.tar.bz2: fim-0.7.0/src/version.h <==
"+FIM_ALLOW_LOADER_STRING_SPECIFICATION  "
"+FIM_AUTHOR  "
"+FIM_AUTHOR_EMAIL  "
"+FIM_AUTHOR_NAME  "
"+FIM_AUTOCMDS  "
"+FIM_AUTOSKIP_FAILED  "
"+FIM_BOZ_PATCH  "
"+FIM_CHECK_DUPLICATES  "
"+FIM_CHECK_FILE_EXISTENCE  "
"+FIM_COMMAND_AUTOCOMPLETION  "
"+FIM_CONFIGURATION  "
"+FIM_DEFAULT_CONFIG  "
"+FIM_DEFAULT_CONFIGURATION  "
"+FIM_DEFAULT_KEY_CONFIG  "
"+FIM_EXPERIMENTAL_ROTATION  "
"+FIM_HANDLE_GIF  "
"+FIM_HANDLE_TIFF  "
"+FIM_HAS_TIMEOUT  "
"+FIM_ITERATED_COMMANDS  "
"+FIM_LINUX_CONSOLEFONTS_DIR_SCAN  "
"+FIM_NAMESPACES  "
"+FIM_NOFB  "
"+FIM_PATHS_IN_MAN  "
"+FIM_PIPE_IMAGE_READ  "
"+FIM_RANDOM  "
"+FIM_READ_DIRS  "
"+FIM_READ_STDIN  "
"+FIM_READ_STDIN_IMAGE  "
"+FIM_RECORDING  "
"+FIM_RECURSIVE_DIRS  "
"+FIM_REMOVE_FAILED  "
"+FIM_SKIP_KNOWN_FILETYPES  "
"+FIM_SMART_COMPLETION  "
"+FIM_SWITCH_FIXUP  "
"+FIM_TMP_FILENAME  "
"+FIM_TRY_CONVERT  "
"+FIM_TRY_DCRAW  "
"+FIM_TRY_DIA  "
"+FIM_TRY_INKSCAPE  "
"+FIM_TRY_XCF2PNM  "
"+FIM_TRY_XFIG  "
"+FIM_USE_READLINE  "
"+FIM_USE_ZCAT  "
"+FIM_VERSION  "
"+FIM_WANT_CUSTOM_INFO_STATUS_BAR  "
"+FIM_WANT_FILENAME_MARK_AND_DUMP  "
"+FIM_WANT_FONT_MAGNIFY_FACTOR  "
"+FIM_WANT_HARDCODED_FONT  "
"+FIM_WANT_LONG_INT  "
"+FIM_WANT_MOUSE  "
"+FIM_WANT_POPEN_CALLS  "
"+FIM_WANT_RAW_BITS_RENDERING  "
"+FIM_WANT_SEEK_MAGIC  "
"+FIM_WANT_SYSTEM_CALLS  "
"+FIM_WANT_TEXT_RENDERING  "
"+FIM_WINDOWS  "
"+FIM_WITH_AALIB  "
"+FIM_WITH_BMP  "
"+FIM_WITH_LIBAVIF  "
"+FIM_WITH_LIBCACA  "
"+FIM_WITH_LIBEXIF  "
"+FIM_WITH_LIBPNG  "
"+FIM_WITH_LIBSDL  "
"+FIM_WITH_LIBWEBP  "
"+FIM_WITH_PCX  "
"\n"
"FIM_AUTHOR = \"Michele Martone <dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_EMAIL = \"<dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_NAME = \"Michele Martone\"\n"
"FIM_CONFIGURATION = \"./configure \"\n"
"FIM_TMP_FILENAME = \"\"\n"
"FIM_VERSION = \"0.7.0\"\n"
"-FIM_BIG_ENDIAN  "
"-FIM_CACHE_DEBUG  "
"-FIM_DEFAULT_CONSOLEFONT  "
"-FIM_HANDLE_QOI  "
"-FIM_KEEP_BROKEN_CONSOLE  "
"-FIM_NOFIMRC  "
"-FIM_NOHISTORY  "
"-FIM_TRY_XCFTOPNM  "
"-FIM_USE_DESIGNATED_INITIALIZERS  "
"-FIM_WANTS_SLOW_RESIZE  "
"-FIM_WANT_EXIFTOOL  "
"-FIM_WANT_FB_CONSOLE_SWITCH_WHILE_LOADING  "
"-FIM_WANT_NOSCRIPTING  "
"-FIM_WANT_NO_OUTPUT_CONSOLE  "
"-FIM_WANT_STATIC_BINARY  "
"-FIM_WITH_ARCHIVE  "
"-FIM_WITH_DEBUG  "
"-FIM_WITH_LIBGTK  "
"-FIM_WITH_LIBIMLIB2  "
"-FIM_WITH_LIBJASPER  "
"-FIM_WITH_LIBXYZ  "
"-FIM_WITH_NO_FRAMEBUFFER  "
"-FIM_WITH_QOI  "
"-FIM_WITH_UFRAW  "
